@@ -295,14 +295,29 @@ void KIOFuseVFS::setUseFileJob(bool useFileJob)
 	m_useFileJob = useFileJob;
 }
 
-void KIOFuseVFS::mountUrl(QUrl url, std::function<void (const QString &, int)> callback)
+void KIOFuseVFS::mountUrl(const QUrl &url, const std::function<void (const QString &, int)> &callback)
 {
+	qDebug(KIOFUSE_LOG) << "Trying to mount" << url;
+
+	if(!url.isValid()) {
+		qDebug(KIOFUSE_LOG) << "Got invalid URL";
+		return callback({}, EINVAL);
+	}
+
+	const auto vfsPath = mapUrlToVfs(url).join(QLatin1Char('/'));
+	// If it's not mounted, this returns an empty QUrl.
+	// Checking with the target URL is done to detect password changes.
+	if(localPathToRemoteUrl(vfsPath) == url) {
+		qDebug(KIOFUSE_LOG) << "Already mounted";
+		return callback(vfsPath, 0);
+	}
+
 	// First make sure it actually exists
 	qDebug(KIOFUSE_LOG) << "Stating" << url.toDisplayString() << "for mount";
 	auto statJob = KIO::stat(url);
 	statJob->setSide(KIO::StatJob::SourceSide); // Be "optimistic" to allow accessing
 	                                            // files over plain HTTP
-	connect(statJob, &KIO::StatJob::result, [=] {
+	connect(statJob, &KIO::StatJob::result, this, [=] {
 		if(statJob->error())
 		{
 			qDebug(KIOFUSE_LOG) << statJob->errorString();
@@ -317,10 +332,12 @@ void KIOFuseVFS::mountUrl(QUrl url, std::function<void (const QString &, int)> c
 	});
 }
 
-QStringList KIOFuseVFS::mapUrlToVfs(QUrl url)
+QStringList KIOFuseVFS::mapUrlToVfs(const QUrl &url)
 {
 	// Build the path where it will appear in the VFS
-	auto targetPathComponents = QStringList{url.scheme(), url.authority()};
+	auto urlWithoutPassword = url;
+	urlWithoutPassword.setPassword({});
+	auto targetPathComponents = QStringList{urlWithoutPassword.scheme(), urlWithoutPassword.authority()};
 	targetPathComponents.append(url.path().split(QLatin1Char('/')));
 
 	// Strip empty path elements, for instance in
@@ -332,13 +349,13 @@ QStringList KIOFuseVFS::mapUrlToVfs(QUrl url)
 	return targetPathComponents;
 }
 
-void KIOFuseVFS::findAndCreateOrigin(QUrl url, QStringList pathElements, std::function<void (const QString &, int)> callback)
+void KIOFuseVFS::findAndCreateOrigin(const QUrl &url, const QStringList &pathElements, const std::function<void (const QString &, int)> &callback)
 {
 	qDebug(KIOFUSE_LOG) << "Trying origin" << url.toDisplayString();
 	auto statJob = KIO::stat(url);
 	statJob->setSide(KIO::StatJob::SourceSide); // Be "optimistic" to allow accessing
 	                                            // files over plain HTTP
-	connect(statJob, &KIO::StatJob::result, [=] {
+	connect(statJob, &KIO::StatJob::result, this, [=] {
 		if(statJob->error())
 		{
 			qDebug(KIOFUSE_LOG) << statJob->errorString();
@@ -395,7 +412,7 @@ void KIOFuseVFS::findAndCreateOrigin(QUrl url, QStringList pathElements, std::fu
 				return callback({}, EIO);
 			}
 
-			// Some ioslaves like man:/ implement "index files" for folders (including /) by making
+			// Some ioworkers like man:/ implement "index files" for folders (including /) by making
 			// them look as regular file when stating, but they also support listDir for directory
 			// functionality. This behaviour is not compatible, so just reject it outright.
 			if((url.path().isEmpty() || url.path() == QStringLiteral("/"))
@@ -602,7 +619,7 @@ void KIOFuseVFS::setattr(fuse_req_t req, fuse_ino_t ino, struct stat *attr, int
 			fileJob->truncate(sharedState->value.st_size);
 			connect(fileJob, &KIO::FileJob::truncated, [=] {
 				fileJob->close();
-				connect(fileJob, qOverload<KIO::Job*>(&KIO::FileJob::close), [=] {
+				connect(fileJob, qOverload<KIO::Job*>(&KIO::FileJob::fileClosed), [=] {
 					fileJobBasedFileNode->m_stat.st_size = sharedState->value.st_size;
 					markOperationCompleted(FUSE_SET_ATTR_SIZE);
 				});
@@ -748,7 +765,7 @@ void KIOFuseVFS::mknod(fuse_req_t req, fuse_ino_t parent, const char *name, mode
 	auto url = addPathElements(that->remoteUrl(node), {nameStr});
 	auto *job = KIO::put(url, mode & ~S_IFMT);
 	// Not connecting to the dataReq signal at all results in an empty file
-	that->connect(job, &KIO::SimpleJob::finished, [=] {
+	that->connect(job, &KIO::SimpleJob::finished, that, [=] {
 		if(job->error())
 		{
 			fuse_reply_err(req, kioErrorToFuseError(job->error()));
@@ -784,7 +801,7 @@ void KIOFuseVFS::mkdir(fuse_req_t req, fuse_ino_t parent, const char *name, mode
 	auto namestr = QString::fromUtf8(name);
 	auto url = addPathElements(that->remoteUrl(node), {namestr});
 	auto *job = KIO::mkdir(url, mode & ~S_IFMT);
-	that->connect(job, &KIO::SimpleJob::finished, [=] {
+	that->connect(job, &KIO::SimpleJob::finished, that, [=] {
 		if(job->error())
 		{
 			fuse_reply_err(req, kioErrorToFuseError(job->error()));
@@ -857,7 +874,7 @@ void KIOFuseVFS::unlinkHelper(fuse_req_t req, fuse_ino_t parent, const char *nam
 	}
 
 	auto *job = KIO::del(that->remoteUrl(node));
-	that->connect(job, &KIO::SimpleJob::finished, [=] {
+	that->connect(job, &KIO::SimpleJob::finished, that, [=] {
 		if(job->error())
 		{
 			fuse_reply_err(req, kioErrorToFuseError(job->error()));
@@ -923,7 +940,7 @@ void KIOFuseVFS::symlink(fuse_req_t req, const char *link, fuse_ino_t parent, co
 	auto namestr = QString::fromUtf8(name);
 	auto url = addPathElements(that->remoteUrl(node), {namestr});
 	auto *job = KIO::symlink(target, url);
-	that->connect(job, &KIO::SimpleJob::finished, [=] {
+	that->connect(job, &KIO::SimpleJob::finished, that, [=] {
 		if(job->error())
 		{
 			fuse_reply_err(req, kioErrorToFuseError(job->error()));
@@ -1013,7 +1030,7 @@ void KIOFuseVFS::rename(fuse_req_t req, fuse_ino_t parent, const char *name, fus
 	     newUrl = addPathElements(that->remoteUrl(remoteNewParent), {newNameStr});
 
 	auto *job = KIO::rename(url, newUrl, (flags & RENAME_NOREPLACE) ? KIO::DefaultFlags : KIO::Overwrite);
-	that->connect(job, &KIO::SimpleJob::finished, [=] {
+	that->connect(job, &KIO::SimpleJob::finished, that, [=] {
 		if(job->error())
 			fuse_reply_err(req, kioErrorToFuseError(job->error()));
 		else
@@ -1231,7 +1248,7 @@ void KIOFuseVFS::read(fuse_req_t req, fuse_ino_t ino, size_t size, off_t off, fu
 				if(off_t(offset) != off)
 				{
 					fileJob->close();
-					fileJob->connect(fileJob, qOverload<KIO::Job*>(&KIO::FileJob::close), [=] {
+					fileJob->connect(fileJob, qOverload<KIO::Job*>(&KIO::FileJob::fileClosed), [=] {
 						fuse_reply_err(req, EIO);
 					});
 					return;
@@ -1257,7 +1274,7 @@ void KIOFuseVFS::read(fuse_req_t req, fuse_ino_t ino, size_t size, off_t off, fu
 						return;
 					}
 					fileJob->close();
-					fileJob->connect(fileJob, qOverload<KIO::Job*>(&KIO::FileJob::close), [=] {
+					fileJob->connect(fileJob, qOverload<KIO::Job*>(&KIO::FileJob::fileClosed), [=] {
 						fuse_reply_buf(req, buffer.constData(), buffer.size());
 					});
 				});
@@ -1353,12 +1370,12 @@ void KIOFuseVFS::write(fuse_req_t req, fuse_ino_t ino, const char *buf, size_t s
 				Q_UNUSED(job);
 				if (off_t(offset) != off) {
 					fileJob->close();
-					fileJob->connect(fileJob, qOverload<KIO::Job*>(&KIO::FileJob::close), [=] {
+					fileJob->connect(fileJob, qOverload<KIO::Job*>(&KIO::FileJob::fileClosed), [=] {
 						fuse_reply_err(req, EIO);
 					});
 					return;
 				}
-				// Limit write to avoid killing the slave.
+				// Limit write to avoid killing the worker.
 				// @see https://phabricator.kde.org/D15448
 				fileJob->write(data.left(0xFFFFFF));
 				off_t bytesLeft = size;
@@ -1372,7 +1389,7 @@ void KIOFuseVFS::write(fuse_req_t req, fuse_ino_t ino, const char *buf, size_t s
 						return;
 					}
 					fileJob->close();
-					fileJob->connect(fileJob, qOverload<KIO::Job*>(&KIO::FileJob::close), [=] {
+					fileJob->connect(fileJob, qOverload<KIO::Job*>(&KIO::FileJob::fileClosed), [=] {
 						// Wait till we've flushed first...
 						remoteNode->m_stat.st_size = std::max(off_t(offset + data.size()), remoteNode->m_stat.st_size);
 						fuse_reply_write(req, data.size());
@@ -1490,7 +1507,7 @@ bool KIOFuseVFS::isEnvironmentValid()
 	return true;
 }
 
-std::shared_ptr<KIOFuseNode> KIOFuseVFS::nodeByName(const std::shared_ptr<KIOFuseDirNode> &parent, const QString name) const
+std::shared_ptr<KIOFuseNode> KIOFuseVFS::nodeByName(const std::shared_ptr<KIOFuseDirNode> &parent, const QString &name) const
 {
 	for(auto ino : parent->m_childrenInos)
 	{
@@ -1739,7 +1756,7 @@ void KIOFuseVFS::markNodeDeleted(const std::shared_ptr<KIOFuseNode> &node)
 void KIOFuseVFS::replyAttr(fuse_req_t req, std::shared_ptr<KIOFuseNode> node)
 {
 	// Set st_blocks accordingly
-	node->m_stat.st_blocks = (node->m_stat.st_size + node->m_stat.st_blksize - 1) / node->m_stat.st_blksize;
+	node->m_stat.st_blocks = (node->m_stat.st_size + 512 - 1) / 512;
 
 	// TODO: Validity timeout?
 	fuse_reply_attr(req, &node->m_stat, 0);
@@ -1763,7 +1780,7 @@ void KIOFuseVFS::replyEntry(fuse_req_t req, std::shared_ptr<KIOFuseNode> node)
 	fuse_reply_entry(req, &entry);
 }
 
-std::shared_ptr<KIOFuseNode> KIOFuseVFS::createNodeFromUDSEntry(const KIO::UDSEntry &entry, const fuse_ino_t parentIno, QString nameOverride)
+std::shared_ptr<KIOFuseNode> KIOFuseVFS::createNodeFromUDSEntry(const KIO::UDSEntry &entry, const fuse_ino_t parentIno, const QString &nameOverride)
 {
 	QString name = nameOverride;
 	if(name.isEmpty())
@@ -1949,7 +1966,7 @@ std::shared_ptr<KIOFuseNode> KIOFuseVFS::updateNodeFromUDSEntry(const std::share
 	return node;
 }
 
-void KIOFuseVFS::awaitBytesAvailable(const std::shared_ptr<KIOFuseRemoteCacheBasedFileNode> &node, off_t bytes, std::function<void(int error)> callback)
+void KIOFuseVFS::awaitBytesAvailable(const std::shared_ptr<KIOFuseRemoteCacheBasedFileNode> &node, off_t bytes, const std::function<void(int error)> &callback)
 {
 	if(bytes < 0)
 	{
@@ -1990,11 +2007,11 @@ void KIOFuseVFS::awaitBytesAvailable(const std::shared_ptr<KIOFuseRemoteCacheBas
 			int cacheFd = fileno(node->m_localCache);
 			if(lseek(cacheFd, 0, SEEK_END) == -1
 			   || !sane_write(cacheFd, data.data(), data.size()))
-				emit node->localCacheChanged(errno);
+				Q_EMIT node->localCacheChanged(errno);
 			else
 			{
 				node->m_cacheSize += data.size();
-				emit node->localCacheChanged(0);
+				Q_EMIT node->localCacheChanged(0);
 			}
 		});
 		connect(job, &KIO::TransferJob::result, [=] {
@@ -2008,7 +2025,7 @@ void KIOFuseVFS::awaitBytesAvailable(const std::shared_ptr<KIOFuseRemoteCacheBas
 				node->m_cacheSize = 0;
 				node->m_cacheComplete = false;
 				node->m_localCache = nullptr;
-				emit node->localCacheChanged(kioErrorToFuseError(job->error()));
+				Q_EMIT node->localCacheChanged(kioErrorToFuseError(job->error()));
 			}
 			else
 			{
@@ -2016,7 +2033,7 @@ void KIOFuseVFS::awaitBytesAvailable(const std::shared_ptr<KIOFuseRemoteCacheBas
 				// This also ensures that the cache is seen as complete.
 				node->m_stat.st_size = node->m_cacheSize;
 				node->m_cacheComplete = true;
-				emit node->localCacheChanged(0);
+				Q_EMIT node->localCacheChanged(0);
 			}
 		});
 	}
@@ -2047,7 +2064,7 @@ void KIOFuseVFS::awaitBytesAvailable(const std::shared_ptr<KIOFuseRemoteCacheBas
 	);
 }
 
-void KIOFuseVFS::awaitCacheComplete(const std::shared_ptr<KIOFuseRemoteCacheBasedFileNode> &node, std::function<void (int)> callback)
+void KIOFuseVFS::awaitCacheComplete(const std::shared_ptr<KIOFuseRemoteCacheBasedFileNode> &node, const std::function<void (int)> &callback)
 {
 	return awaitBytesAvailable(node, std::numeric_limits<off_t>::max(), [callback](int error) {
 		// ESPIPE == cache complete, but less than the requested size, which is expected.
@@ -2055,7 +2072,7 @@ void KIOFuseVFS::awaitCacheComplete(const std::shared_ptr<KIOFuseRemoteCacheBase
 	});
 }
 
-void KIOFuseVFS::awaitChildrenComplete(const std::shared_ptr<KIOFuseDirNode> &node, std::function<void (int)> callback)
+void KIOFuseVFS::awaitChildrenComplete(const std::shared_ptr<KIOFuseDirNode> &node, const std::function<void (int)> &callback)
 {
 	auto remoteNode = std::dynamic_pointer_cast<KIOFuseRemoteDirNode>(node);
 	if(!remoteNode)
@@ -2074,7 +2091,7 @@ void KIOFuseVFS::awaitChildrenComplete(const std::shared_ptr<KIOFuseDirNode> &no
 		// List the remote dir
 		auto refreshTime = std::chrono::steady_clock::now();
 		auto *job = KIO::listDir(remoteUrl(remoteNode));
-		connect(job, &KIO::ListJob::entries, [=](auto *job, const KIO::UDSEntryList &entries) {
+		connect(job, &KIO::ListJob::entries, this, [=](auto *job, const KIO::UDSEntryList &entries) {
 			for(auto &entry : entries)
 			{
 				// Inside the loop because refreshing "." might drop it
@@ -2118,12 +2135,12 @@ void KIOFuseVFS::awaitChildrenComplete(const std::shared_ptr<KIOFuseDirNode> &no
 				insertNode(childrenNode);
 			}
 		});
-		connect(job, &KIO::ListJob::result, [=] {
+		connect(job, &KIO::ListJob::result, this, [=] {
 			remoteNode->m_childrenRequested = false;
 
 			if(job->error() && job->error() != KJob::KilledJobError)
 			{
-				emit remoteNode->gotChildren(kioErrorToFuseError(job->error()));
+				Q_EMIT remoteNode->gotChildren(kioErrorToFuseError(job->error()));
 				return;
 			}
 
@@ -2136,7 +2153,7 @@ void KIOFuseVFS::awaitChildrenComplete(const std::shared_ptr<KIOFuseDirNode> &no
 			}
 
 			remoteNode->m_lastChildrenRefresh = refreshTime;
-			emit remoteNode->gotChildren(0);
+			Q_EMIT remoteNode->gotChildren(0);
 		});
 
 		remoteNode->m_childrenRequested = true;
@@ -2162,7 +2179,7 @@ void KIOFuseVFS::markCacheDirty(const std::shared_ptr<KIOFuseRemoteCacheBasedFil
 	m_dirtyNodes.insert(node->m_stat.st_ino);
 }
 
-void KIOFuseVFS::awaitNodeFlushed(const std::shared_ptr<KIOFuseRemoteCacheBasedFileNode> &node, std::function<void (int)> callback)
+void KIOFuseVFS::awaitNodeFlushed(const std::shared_ptr<KIOFuseRemoteCacheBasedFileNode> &node, const std::function<void (int)> &callback)
 {
 	if(!node->m_cacheDirty && !node->m_flushRunning)
 		return callback(0); // Nothing to flush/wait for
@@ -2198,7 +2215,7 @@ void KIOFuseVFS::awaitNodeFlushed(const std::shared_ptr<KIOFuseRemoteCacheBasedF
 		job->setTotalSize(node->m_cacheSize);
 
 		off_t bytesSent = 0; // Modified inside the lambda
-		connect(job, &KIO::TransferJob::dataReq, [=](auto *job, QByteArray &data) mutable {
+		connect(job, &KIO::TransferJob::dataReq, this, [=](auto *job, QByteArray &data) mutable {
 			Q_UNUSED(job);
 
 			// Someone truncated the file?
@@ -2232,14 +2249,14 @@ void KIOFuseVFS::awaitNodeFlushed(const std::shared_ptr<KIOFuseRemoteCacheBasedF
 
 			bytesSent += toSend;
 		});
-		connect(job, &KIO::TransferJob::result, [=] {
+		connect(job, &KIO::TransferJob::result, this, [=] {
 			node->m_flushRunning = false;
 
 			if(job->error())
 			{
 				qWarning(KIOFUSE_LOG) << "Failed to send data:" << job->errorString();
 				markCacheDirty(node); // Try again
-				emit node->cacheFlushed(kioErrorToFuseError(job->error()));
+				Q_EMIT node->cacheFlushed(kioErrorToFuseError(job->error()));
 				return;
 			}
 
@@ -2248,7 +2265,7 @@ void KIOFuseVFS::awaitNodeFlushed(const std::shared_ptr<KIOFuseRemoteCacheBasedF
 				// Nobody wrote to the cache while sending data
 				m_dirtyNodes.extract(node->m_stat.st_ino);
 				node->m_numKilledJobs = 0;
-				emit node->cacheFlushed(0);
+				Q_EMIT node->cacheFlushed(0);
 			}
 			else
 				awaitNodeFlushed(node, [](int){});
@@ -2266,7 +2283,7 @@ void KIOFuseVFS::awaitNodeFlushed(const std::shared_ptr<KIOFuseRemoteCacheBasedF
 	);
 }
 
-void KIOFuseVFS::awaitAttrRefreshed(const std::shared_ptr<KIOFuseNode> &node, std::function<void (int)> callback)
+void KIOFuseVFS::awaitAttrRefreshed(const std::shared_ptr<KIOFuseNode> &node, const std::function<void (int)> &callback)
 {
 	auto remoteNode = std::dynamic_pointer_cast<KIOFuseRemoteNodeInfo>(node);
 	if(!remoteNode || !remoteNode->hasStatTimedOut())
@@ -2289,7 +2306,7 @@ void KIOFuseVFS::awaitAttrRefreshed(const std::shared_ptr<KIOFuseNode> &node, st
 
 			Q_UNUSED(mountedNode);
 			remoteNode->m_statRequested = false;
-			emit remoteNode->statRefreshed(error);
+			Q_EMIT remoteNode->statRefreshed(error);
 		});
 	}
 
@@ -2304,7 +2321,7 @@ void KIOFuseVFS::awaitAttrRefreshed(const std::shared_ptr<KIOFuseNode> &node, st
 	);
 }
 
-void KIOFuseVFS::awaitChildMounted(const std::shared_ptr<KIOFuseRemoteDirNode> &parent, const QString name, std::function<void (const std::shared_ptr<KIOFuseNode> &, int)> callback)
+void KIOFuseVFS::awaitChildMounted(const std::shared_ptr<KIOFuseRemoteDirNode> &parent, const QString &name, const std::function<void (const std::shared_ptr<KIOFuseNode> &, int)> &callback)
 {
 	auto url = addPathElements(remoteUrl(parent), {name});
 	if(url.isEmpty()) // Not remote?
@@ -2319,7 +2336,7 @@ void KIOFuseVFS::awaitChildMounted(const std::shared_ptr<KIOFuseRemoteDirNode> &
 	auto statJob = KIO::stat(url);
 	statJob->setSide(KIO::StatJob::SourceSide); // Be "optimistic" to allow accessing
 	                                            // files over plain HTTP
-	connect(statJob, &KIO::StatJob::result, [=] {
+	connect(statJob, &KIO::StatJob::result, this, [=] {
 		if(statJob->error())
 		{
 			qDebug(KIOFUSE_LOG) << statJob->errorString();
@@ -2347,7 +2364,7 @@ void KIOFuseVFS::awaitChildMounted(const std::shared_ptr<KIOFuseRemoteDirNode> &
 	});
 }
 
-QUrl KIOFuseVFS::originOfUrl(QUrl url)
+QUrl KIOFuseVFS::originOfUrl(const QUrl &url)
 {
 	QUrl originUrl = url;
 	if(originUrl.path().startsWith(QLatin1Char('/')))
@@ -2461,7 +2478,7 @@ int KIOFuseVFS::kioErrorToFuseError(const int kioError) {
 		case KIO::ERR_CANNOT_RENAME                : return EIO;
 		case KIO::ERR_CANNOT_CHMOD                 : return EIO;
 		case KIO::ERR_CANNOT_DELETE                : return EIO;
-		case KIO::ERR_SLAVE_DIED                   : return EIO;
+		case KIO::ERR_WORKER_DIED                  : return EIO;
 		case KIO::ERR_OUT_OF_MEMORY                : return ENOMEM;
 		case KIO::ERR_UNKNOWN_PROXY_HOST           : return EHOSTUNREACH;
 		case KIO::ERR_CANNOT_AUTHENTICATE          : return EACCES;
@@ -2477,10 +2494,10 @@ int KIOFuseVFS::kioErrorToFuseError(const int kioError) {
 		case KIO::ERR_CANNOT_RENAME_PARTIAL        : return EIO;
 		case KIO::ERR_NEED_PASSWD                  : return EACCES;
 		case KIO::ERR_CANNOT_SYMLINK               : return EIO;
-		case KIO::ERR_NO_CONTENT                   : return ENODATA;
+		case KIO::ERR_NO_CONTENT                   : return EIO;
 		case KIO::ERR_DISK_FULL                    : return ENOSPC;
 		case KIO::ERR_IDENTICAL_FILES              : return EEXIST;
-		case KIO::ERR_SLAVE_DEFINED                : return EIO;
+		case KIO::ERR_WORKER_DEFINED               : return EIO;
 		case KIO::ERR_UPGRADE_REQUIRED             : return EPROTOTYPE;
 		case KIO::ERR_POST_DENIED                  : return EACCES;
 		case KIO::ERR_CANNOT_SEEK                  : return EIO;
@@ -2490,7 +2507,7 @@ int KIOFuseVFS::kioErrorToFuseError(const int kioError) {
 		case KIO::ERR_DROP_ON_ITSELF               : return EINVAL;
 		case KIO::ERR_CANNOT_MOVE_INTO_ITSELF      : return EINVAL;
 		case KIO::ERR_PASSWD_SERVER                : return EIO;
-		case KIO::ERR_CANNOT_CREATE_SLAVE          : return EIO;
+		case KIO::ERR_CANNOT_CREATE_WORKER         : return EIO;
 		case KIO::ERR_FILE_TOO_LARGE_FOR_FAT32     : return EFBIG;
 		case KIO::ERR_OWNER_DIED                   : return EIO;
 		default                                    : return EIO;
