@@ -56,12 +56,12 @@ private Q_SLOTS:
 #endif // WASTE_DISK_SPACE
 
 private:
-	QDateTime roundDownToSecond(QDateTime dt);
+	QDateTime roundDownToSecond(const QDateTime &dt);
 	bool forceNodeTimeout();
 	/** Unlike QFileInfo::symLinkTarget, which returns absolute paths only,
 	  * this returns the raw link content. On failure or truncation, a null
 	  * QString is returned instead. */
-	QString readlink(QString symlink);
+	QString readlink(const QString &symlink);
 
 	org::kde::KIOFuse::VFS m_kiofuse_iface{QStringLiteral("org.kde.KIOFuse"),
 		                                   QStringLiteral("/org/kde/KIOFuse"),
@@ -131,7 +131,7 @@ void FileOpsTest::testLocalPathToRemoteUrl()
 	// mtp:/ -> Remote URL can't possibly be location of KIOFuse mount.
 	// / -> Root can't possibly be location of KIOFuse mount.
 	// m_mountDir -> Whilst this is in the KIOFuse mount, no remote URL exists for it
-	for(auto url : {QStringLiteral("mtp:/"), QStringLiteral("/"), m_mountDir.path()})
+	for(const auto &url : {QStringLiteral("mtp:/"), QStringLiteral("/"), m_mountDir.path()})
 	{
 		errorReply = m_kiofuse_iface.remoteUrl(url);
 		errorReply.waitForFinished();
@@ -683,7 +683,7 @@ void FileOpsTest::testArchiveOps()
 
 void FileOpsTest::testManWorkaround()
 {
-	// The man ioslave has "hybrid" directories which stat as regular files but also support
+	// The man ioworker has "hybrid" directories which stat as regular files but also support
 	// listDir. This behaviour is not supported and mounting has to fail.
 
 	if (!KProtocolInfo::isKnownProtocol(QStringLiteral("man")))
@@ -1029,9 +1029,9 @@ void FileOpsTest::testReadWrite4GBFile()
 }
 #endif // WASTE_DISK_SPACE
 
-QDateTime FileOpsTest::roundDownToSecond(QDateTime dt)
+QDateTime FileOpsTest::roundDownToSecond(const QDateTime &dt)
 {
-	return QDateTime::fromTime_t(dt.toTime_t());
+	return dt.addMSecs(-dt.time().msec());
 }
 
 bool FileOpsTest::forceNodeTimeout()
@@ -1041,7 +1041,7 @@ bool FileOpsTest::forceNodeTimeout()
 	return !reply.isError();
 }
 
-QString FileOpsTest::readlink(QString symlink)
+QString FileOpsTest::readlink(const QString &symlink)
 {
 	char buf[PATH_MAX];
 	int len = ::readlink(qPrintable(symlink), buf, sizeof(buf));
